"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.amenity_1 import (
    Amenity1,
)


class Location1(object):
    """Implementation of the 'Location1' model.

    Attributes:
        business_id (int): The model property of type int.
        site_id (int): The model property of type int.
        business_description (str): The model property of type str.
        additional_image_ur_ls (List[str]): The model property of type List[str].
        facility_square_feet (int): The model property of type int.
        pro_spa_finder_site (bool): The model property of type bool.
        has_classes (bool): The model property of type bool.
        phone_extension (str): The model property of type str.
        action (ActionEnum): The model property of type ActionEnum.
        id (int): The model property of type int.
        name (str): The model property of type str.
        address (str): The model property of type str.
        address_2 (str): The model property of type str.
        tax_1 (float): The model property of type float.
        tax_2 (float): The model property of type float.
        tax_3 (float): The model property of type float.
        tax_4 (float): The model property of type float.
        tax_5 (float): The model property of type float.
        phone (str): The model property of type str.
        city (str): The model property of type str.
        state_prov_code (str): The model property of type str.
        postal_code (str): The model property of type str.
        latitude (float): The model property of type float.
        longitude (float): The model property of type float.
        distance_in_miles (float): The model property of type float.
        image_url (str): The model property of type str.
        description (str): The model property of type str.
        has_site (bool): The model property of type bool.
        can_book (bool): The model property of type bool.
        number_treatment_rooms (int): The model property of type int.
        active (bool): The model property of type bool.
        inv_active (bool): The model property of type bool.
        ws_show (bool): The model property of type bool.
        email (str): The model property of type str.
        contact_name (str): The model property of type str.
        ship_address (str): The model property of type str.
        ship_state (str): The model property of type str.
        ship_postal (str): The model property of type str.
        ship_phone (str): The model property of type str.
        ship_poc (str): The model property of type str.
        tax_grouping (bool): The model property of type bool.
        label_tax_1 (str): The model property of type str.
        label_tax_2 (str): The model property of type str.
        label_tax_3 (str): The model property of type str.
        label_tax_4 (str): The model property of type str.
        label_tax_5 (str): The model property of type str.
        wac (bool): The model property of type bool.
        ship_address_2 (str): The model property of type str.
        master_loc_id (int): The model property of type int.
        street_address (str): The model property of type str.
        country (str): The model property of type str.
        ext (str): The model property of type str.
        amenities (List[Amenity1]): The model property of type List[Amenity1].
        total_number_of_deals (int): The model property of type int.
        total_number_of_ratings (int): The model property of type int.
        average_rating (float): The model property of type float.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "business_id": "BusinessId",
        "site_id": "SiteId",
        "business_description": "BusinessDescription",
        "additional_image_ur_ls": "AdditionalImageURLs",
        "facility_square_feet": "FacilitySquareFeet",
        "pro_spa_finder_site": "ProSpaFinderSite",
        "has_classes": "HasClasses",
        "phone_extension": "PhoneExtension",
        "action": "Action",
        "id": "Id",
        "name": "Name",
        "address": "Address",
        "address_2": "Address2",
        "tax_1": "Tax1",
        "tax_2": "Tax2",
        "tax_3": "Tax3",
        "tax_4": "Tax4",
        "tax_5": "Tax5",
        "phone": "Phone",
        "city": "City",
        "state_prov_code": "StateProvCode",
        "postal_code": "PostalCode",
        "latitude": "Latitude",
        "longitude": "Longitude",
        "distance_in_miles": "DistanceInMiles",
        "image_url": "ImageURL",
        "description": "Description",
        "has_site": "HasSite",
        "can_book": "CanBook",
        "number_treatment_rooms": "NumberTreatmentRooms",
        "active": "Active",
        "inv_active": "InvActive",
        "ws_show": "WsShow",
        "email": "Email",
        "contact_name": "ContactName",
        "ship_address": "ShipAddress",
        "ship_state": "ShipState",
        "ship_postal": "ShipPostal",
        "ship_phone": "ShipPhone",
        "ship_poc": "ShipPOC",
        "tax_grouping": "TaxGrouping",
        "label_tax_1": "LabelTax1",
        "label_tax_2": "LabelTax2",
        "label_tax_3": "LabelTax3",
        "label_tax_4": "LabelTax4",
        "label_tax_5": "LabelTax5",
        "wac": "WAC",
        "ship_address_2": "ShipAddress2",
        "master_loc_id": "MasterLocId",
        "street_address": "StreetAddress",
        "country": "Country",
        "ext": "Ext",
        "amenities": "Amenities",
        "total_number_of_deals": "TotalNumberOfDeals",
        "total_number_of_ratings": "TotalNumberOfRatings",
        "average_rating": "AverageRating",
    }

    _optionals = [
        "business_id",
        "site_id",
        "business_description",
        "additional_image_ur_ls",
        "facility_square_feet",
        "pro_spa_finder_site",
        "has_classes",
        "phone_extension",
        "action",
        "id",
        "name",
        "address",
        "address_2",
        "tax_1",
        "tax_2",
        "tax_3",
        "tax_4",
        "tax_5",
        "phone",
        "city",
        "state_prov_code",
        "postal_code",
        "latitude",
        "longitude",
        "distance_in_miles",
        "image_url",
        "description",
        "has_site",
        "can_book",
        "number_treatment_rooms",
        "active",
        "inv_active",
        "ws_show",
        "email",
        "contact_name",
        "ship_address",
        "ship_state",
        "ship_postal",
        "ship_phone",
        "ship_poc",
        "tax_grouping",
        "label_tax_1",
        "label_tax_2",
        "label_tax_3",
        "label_tax_4",
        "label_tax_5",
        "wac",
        "ship_address_2",
        "master_loc_id",
        "street_address",
        "country",
        "ext",
        "amenities",
        "total_number_of_deals",
        "total_number_of_ratings",
        "average_rating",
    ]

    def __init__(
        self,
        business_id=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        business_description=APIHelper.SKIP,
        additional_image_ur_ls=APIHelper.SKIP,
        facility_square_feet=APIHelper.SKIP,
        pro_spa_finder_site=APIHelper.SKIP,
        has_classes=APIHelper.SKIP,
        phone_extension=APIHelper.SKIP,
        action=APIHelper.SKIP,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        address=APIHelper.SKIP,
        address_2=APIHelper.SKIP,
        tax_1=APIHelper.SKIP,
        tax_2=APIHelper.SKIP,
        tax_3=APIHelper.SKIP,
        tax_4=APIHelper.SKIP,
        tax_5=APIHelper.SKIP,
        phone=APIHelper.SKIP,
        city=APIHelper.SKIP,
        state_prov_code=APIHelper.SKIP,
        postal_code=APIHelper.SKIP,
        latitude=APIHelper.SKIP,
        longitude=APIHelper.SKIP,
        distance_in_miles=APIHelper.SKIP,
        image_url=APIHelper.SKIP,
        description=APIHelper.SKIP,
        has_site=APIHelper.SKIP,
        can_book=APIHelper.SKIP,
        number_treatment_rooms=APIHelper.SKIP,
        active=APIHelper.SKIP,
        inv_active=APIHelper.SKIP,
        ws_show=APIHelper.SKIP,
        email=APIHelper.SKIP,
        contact_name=APIHelper.SKIP,
        ship_address=APIHelper.SKIP,
        ship_state=APIHelper.SKIP,
        ship_postal=APIHelper.SKIP,
        ship_phone=APIHelper.SKIP,
        ship_poc=APIHelper.SKIP,
        tax_grouping=APIHelper.SKIP,
        label_tax_1=APIHelper.SKIP,
        label_tax_2=APIHelper.SKIP,
        label_tax_3=APIHelper.SKIP,
        label_tax_4=APIHelper.SKIP,
        label_tax_5=APIHelper.SKIP,
        wac=APIHelper.SKIP,
        ship_address_2=APIHelper.SKIP,
        master_loc_id=APIHelper.SKIP,
        street_address=APIHelper.SKIP,
        country=APIHelper.SKIP,
        ext=APIHelper.SKIP,
        amenities=APIHelper.SKIP,
        total_number_of_deals=APIHelper.SKIP,
        total_number_of_ratings=APIHelper.SKIP,
        average_rating=APIHelper.SKIP):
        """Initialize a Location1 instance."""
        # Initialize members of the class
        if business_id is not APIHelper.SKIP:
            self.business_id = business_id
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if business_description is not APIHelper.SKIP:
            self.business_description = business_description
        if additional_image_ur_ls is not APIHelper.SKIP:
            self.additional_image_ur_ls = additional_image_ur_ls
        if facility_square_feet is not APIHelper.SKIP:
            self.facility_square_feet = facility_square_feet
        if pro_spa_finder_site is not APIHelper.SKIP:
            self.pro_spa_finder_site = pro_spa_finder_site
        if has_classes is not APIHelper.SKIP:
            self.has_classes = has_classes
        if phone_extension is not APIHelper.SKIP:
            self.phone_extension = phone_extension
        if action is not APIHelper.SKIP:
            self.action = action
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if address is not APIHelper.SKIP:
            self.address = address
        if address_2 is not APIHelper.SKIP:
            self.address_2 = address_2
        if tax_1 is not APIHelper.SKIP:
            self.tax_1 = tax_1
        if tax_2 is not APIHelper.SKIP:
            self.tax_2 = tax_2
        if tax_3 is not APIHelper.SKIP:
            self.tax_3 = tax_3
        if tax_4 is not APIHelper.SKIP:
            self.tax_4 = tax_4
        if tax_5 is not APIHelper.SKIP:
            self.tax_5 = tax_5
        if phone is not APIHelper.SKIP:
            self.phone = phone
        if city is not APIHelper.SKIP:
            self.city = city
        if state_prov_code is not APIHelper.SKIP:
            self.state_prov_code = state_prov_code
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code
        if latitude is not APIHelper.SKIP:
            self.latitude = latitude
        if longitude is not APIHelper.SKIP:
            self.longitude = longitude
        if distance_in_miles is not APIHelper.SKIP:
            self.distance_in_miles = distance_in_miles
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url
        if description is not APIHelper.SKIP:
            self.description = description
        if has_site is not APIHelper.SKIP:
            self.has_site = has_site
        if can_book is not APIHelper.SKIP:
            self.can_book = can_book
        if number_treatment_rooms is not APIHelper.SKIP:
            self.number_treatment_rooms = number_treatment_rooms
        if active is not APIHelper.SKIP:
            self.active = active
        if inv_active is not APIHelper.SKIP:
            self.inv_active = inv_active
        if ws_show is not APIHelper.SKIP:
            self.ws_show = ws_show
        if email is not APIHelper.SKIP:
            self.email = email
        if contact_name is not APIHelper.SKIP:
            self.contact_name = contact_name
        if ship_address is not APIHelper.SKIP:
            self.ship_address = ship_address
        if ship_state is not APIHelper.SKIP:
            self.ship_state = ship_state
        if ship_postal is not APIHelper.SKIP:
            self.ship_postal = ship_postal
        if ship_phone is not APIHelper.SKIP:
            self.ship_phone = ship_phone
        if ship_poc is not APIHelper.SKIP:
            self.ship_poc = ship_poc
        if tax_grouping is not APIHelper.SKIP:
            self.tax_grouping = tax_grouping
        if label_tax_1 is not APIHelper.SKIP:
            self.label_tax_1 = label_tax_1
        if label_tax_2 is not APIHelper.SKIP:
            self.label_tax_2 = label_tax_2
        if label_tax_3 is not APIHelper.SKIP:
            self.label_tax_3 = label_tax_3
        if label_tax_4 is not APIHelper.SKIP:
            self.label_tax_4 = label_tax_4
        if label_tax_5 is not APIHelper.SKIP:
            self.label_tax_5 = label_tax_5
        if wac is not APIHelper.SKIP:
            self.wac = wac
        if ship_address_2 is not APIHelper.SKIP:
            self.ship_address_2 = ship_address_2
        if master_loc_id is not APIHelper.SKIP:
            self.master_loc_id = master_loc_id
        if street_address is not APIHelper.SKIP:
            self.street_address = street_address
        if country is not APIHelper.SKIP:
            self.country = country
        if ext is not APIHelper.SKIP:
            self.ext = ext
        if amenities is not APIHelper.SKIP:
            self.amenities = amenities
        if total_number_of_deals is not APIHelper.SKIP:
            self.total_number_of_deals = total_number_of_deals
        if total_number_of_ratings is not APIHelper.SKIP:
            self.total_number_of_ratings = total_number_of_ratings
        if average_rating is not APIHelper.SKIP:
            self.average_rating = average_rating

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        business_id =\
            dictionary.get("BusinessId")\
            if dictionary.get("BusinessId")\
                else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        business_description =\
            dictionary.get("BusinessDescription")\
            if dictionary.get("BusinessDescription")\
                else APIHelper.SKIP
        additional_image_ur_ls =\
            dictionary.get("AdditionalImageURLs")\
            if dictionary.get("AdditionalImageURLs")\
                else APIHelper.SKIP
        facility_square_feet =\
            dictionary.get("FacilitySquareFeet")\
            if dictionary.get("FacilitySquareFeet")\
                else APIHelper.SKIP
        pro_spa_finder_site =\
            dictionary.get("ProSpaFinderSite")\
            if "ProSpaFinderSite" in dictionary.keys()\
                else APIHelper.SKIP
        has_classes =\
            dictionary.get("HasClasses")\
            if "HasClasses" in dictionary.keys()\
                else APIHelper.SKIP
        phone_extension =\
            dictionary.get("PhoneExtension")\
            if dictionary.get("PhoneExtension")\
                else APIHelper.SKIP
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        address =\
            dictionary.get("Address")\
            if dictionary.get("Address")\
                else APIHelper.SKIP
        address_2 =\
            dictionary.get("Address2")\
            if dictionary.get("Address2")\
                else APIHelper.SKIP
        tax_1 =\
            dictionary.get("Tax1")\
            if dictionary.get("Tax1")\
                else APIHelper.SKIP
        tax_2 =\
            dictionary.get("Tax2")\
            if dictionary.get("Tax2")\
                else APIHelper.SKIP
        tax_3 =\
            dictionary.get("Tax3")\
            if dictionary.get("Tax3")\
                else APIHelper.SKIP
        tax_4 =\
            dictionary.get("Tax4")\
            if dictionary.get("Tax4")\
                else APIHelper.SKIP
        tax_5 =\
            dictionary.get("Tax5")\
            if dictionary.get("Tax5")\
                else APIHelper.SKIP
        phone =\
            dictionary.get("Phone")\
            if dictionary.get("Phone")\
                else APIHelper.SKIP
        city =\
            dictionary.get("City")\
            if dictionary.get("City")\
                else APIHelper.SKIP
        state_prov_code =\
            dictionary.get("StateProvCode")\
            if dictionary.get("StateProvCode")\
                else APIHelper.SKIP
        postal_code =\
            dictionary.get("PostalCode")\
            if dictionary.get("PostalCode")\
                else APIHelper.SKIP
        latitude =\
            dictionary.get("Latitude")\
            if dictionary.get("Latitude")\
                else APIHelper.SKIP
        longitude =\
            dictionary.get("Longitude")\
            if dictionary.get("Longitude")\
                else APIHelper.SKIP
        distance_in_miles =\
            dictionary.get("DistanceInMiles")\
            if dictionary.get("DistanceInMiles")\
                else APIHelper.SKIP
        image_url =\
            dictionary.get("ImageURL")\
            if dictionary.get("ImageURL")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        has_site =\
            dictionary.get("HasSite")\
            if "HasSite" in dictionary.keys()\
                else APIHelper.SKIP
        can_book =\
            dictionary.get("CanBook")\
            if "CanBook" in dictionary.keys()\
                else APIHelper.SKIP
        number_treatment_rooms =\
            dictionary.get("NumberTreatmentRooms")\
            if dictionary.get("NumberTreatmentRooms")\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        inv_active =\
            dictionary.get("InvActive")\
            if "InvActive" in dictionary.keys()\
                else APIHelper.SKIP
        ws_show =\
            dictionary.get("WsShow")\
            if "WsShow" in dictionary.keys()\
                else APIHelper.SKIP
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP
        contact_name =\
            dictionary.get("ContactName")\
            if dictionary.get("ContactName")\
                else APIHelper.SKIP
        ship_address =\
            dictionary.get("ShipAddress")\
            if dictionary.get("ShipAddress")\
                else APIHelper.SKIP
        ship_state =\
            dictionary.get("ShipState")\
            if dictionary.get("ShipState")\
                else APIHelper.SKIP
        ship_postal =\
            dictionary.get("ShipPostal")\
            if dictionary.get("ShipPostal")\
                else APIHelper.SKIP
        ship_phone =\
            dictionary.get("ShipPhone")\
            if dictionary.get("ShipPhone")\
                else APIHelper.SKIP
        ship_poc =\
            dictionary.get("ShipPOC")\
            if dictionary.get("ShipPOC")\
                else APIHelper.SKIP
        tax_grouping =\
            dictionary.get("TaxGrouping")\
            if "TaxGrouping" in dictionary.keys()\
                else APIHelper.SKIP
        label_tax_1 =\
            dictionary.get("LabelTax1")\
            if dictionary.get("LabelTax1")\
                else APIHelper.SKIP
        label_tax_2 =\
            dictionary.get("LabelTax2")\
            if dictionary.get("LabelTax2")\
                else APIHelper.SKIP
        label_tax_3 =\
            dictionary.get("LabelTax3")\
            if dictionary.get("LabelTax3")\
                else APIHelper.SKIP
        label_tax_4 =\
            dictionary.get("LabelTax4")\
            if dictionary.get("LabelTax4")\
                else APIHelper.SKIP
        label_tax_5 =\
            dictionary.get("LabelTax5")\
            if dictionary.get("LabelTax5")\
                else APIHelper.SKIP
        wac =\
            dictionary.get("WAC")\
            if "WAC" in dictionary.keys()\
                else APIHelper.SKIP
        ship_address_2 =\
            dictionary.get("ShipAddress2")\
            if dictionary.get("ShipAddress2")\
                else APIHelper.SKIP
        master_loc_id =\
            dictionary.get("MasterLocId")\
            if dictionary.get("MasterLocId")\
                else APIHelper.SKIP
        street_address =\
            dictionary.get("StreetAddress")\
            if dictionary.get("StreetAddress")\
                else APIHelper.SKIP
        country =\
            dictionary.get("Country")\
            if dictionary.get("Country")\
                else APIHelper.SKIP
        ext =\
            dictionary.get("Ext")\
            if dictionary.get("Ext")\
                else APIHelper.SKIP
        amenities = None
        if dictionary.get("Amenities") is not None:
            amenities = [
                Amenity1.from_dictionary(x)
                    for x in dictionary.get("Amenities")
            ]
        else:
            amenities = APIHelper.SKIP
        total_number_of_deals =\
            dictionary.get("TotalNumberOfDeals")\
            if dictionary.get("TotalNumberOfDeals")\
                else APIHelper.SKIP
        total_number_of_ratings =\
            dictionary.get("TotalNumberOfRatings")\
            if dictionary.get("TotalNumberOfRatings")\
                else APIHelper.SKIP
        average_rating =\
            dictionary.get("AverageRating")\
            if dictionary.get("AverageRating")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(business_id,
                   site_id,
                   business_description,
                   additional_image_ur_ls,
                   facility_square_feet,
                   pro_spa_finder_site,
                   has_classes,
                   phone_extension,
                   action,
                   id,
                   name,
                   address,
                   address_2,
                   tax_1,
                   tax_2,
                   tax_3,
                   tax_4,
                   tax_5,
                   phone,
                   city,
                   state_prov_code,
                   postal_code,
                   latitude,
                   longitude,
                   distance_in_miles,
                   image_url,
                   description,
                   has_site,
                   can_book,
                   number_treatment_rooms,
                   active,
                   inv_active,
                   ws_show,
                   email,
                   contact_name,
                   ship_address,
                   ship_state,
                   ship_postal,
                   ship_phone,
                   ship_poc,
                   tax_grouping,
                   label_tax_1,
                   label_tax_2,
                   label_tax_3,
                   label_tax_4,
                   label_tax_5,
                   wac,
                   ship_address_2,
                   master_loc_id,
                   street_address,
                   country,
                   ext,
                   amenities,
                   total_number_of_deals,
                   total_number_of_ratings,
                   average_rating)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _business_id=(
            self.business_id
            if hasattr(self, "business_id")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _business_description=(
            self.business_description
            if hasattr(self, "business_description")
            else None
        )
        _additional_image_ur_ls=(
            self.additional_image_ur_ls
            if hasattr(self, "additional_image_ur_ls")
            else None
        )
        _facility_square_feet=(
            self.facility_square_feet
            if hasattr(self, "facility_square_feet")
            else None
        )
        _pro_spa_finder_site=(
            self.pro_spa_finder_site
            if hasattr(self, "pro_spa_finder_site")
            else None
        )
        _has_classes=(
            self.has_classes
            if hasattr(self, "has_classes")
            else None
        )
        _phone_extension=(
            self.phone_extension
            if hasattr(self, "phone_extension")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _tax_1=(
            self.tax_1
            if hasattr(self, "tax_1")
            else None
        )
        _tax_2=(
            self.tax_2
            if hasattr(self, "tax_2")
            else None
        )
        _tax_3=(
            self.tax_3
            if hasattr(self, "tax_3")
            else None
        )
        _tax_4=(
            self.tax_4
            if hasattr(self, "tax_4")
            else None
        )
        _tax_5=(
            self.tax_5
            if hasattr(self, "tax_5")
            else None
        )
        _phone=(
            self.phone
            if hasattr(self, "phone")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _state_prov_code=(
            self.state_prov_code
            if hasattr(self, "state_prov_code")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _latitude=(
            self.latitude
            if hasattr(self, "latitude")
            else None
        )
        _longitude=(
            self.longitude
            if hasattr(self, "longitude")
            else None
        )
        _distance_in_miles=(
            self.distance_in_miles
            if hasattr(self, "distance_in_miles")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _has_site=(
            self.has_site
            if hasattr(self, "has_site")
            else None
        )
        _can_book=(
            self.can_book
            if hasattr(self, "can_book")
            else None
        )
        _number_treatment_rooms=(
            self.number_treatment_rooms
            if hasattr(self, "number_treatment_rooms")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _inv_active=(
            self.inv_active
            if hasattr(self, "inv_active")
            else None
        )
        _ws_show=(
            self.ws_show
            if hasattr(self, "ws_show")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _ship_address=(
            self.ship_address
            if hasattr(self, "ship_address")
            else None
        )
        _ship_state=(
            self.ship_state
            if hasattr(self, "ship_state")
            else None
        )
        _ship_postal=(
            self.ship_postal
            if hasattr(self, "ship_postal")
            else None
        )
        _ship_phone=(
            self.ship_phone
            if hasattr(self, "ship_phone")
            else None
        )
        _ship_poc=(
            self.ship_poc
            if hasattr(self, "ship_poc")
            else None
        )
        _tax_grouping=(
            self.tax_grouping
            if hasattr(self, "tax_grouping")
            else None
        )
        _label_tax_1=(
            self.label_tax_1
            if hasattr(self, "label_tax_1")
            else None
        )
        _label_tax_2=(
            self.label_tax_2
            if hasattr(self, "label_tax_2")
            else None
        )
        _label_tax_3=(
            self.label_tax_3
            if hasattr(self, "label_tax_3")
            else None
        )
        _label_tax_4=(
            self.label_tax_4
            if hasattr(self, "label_tax_4")
            else None
        )
        _label_tax_5=(
            self.label_tax_5
            if hasattr(self, "label_tax_5")
            else None
        )
        _wac=(
            self.wac
            if hasattr(self, "wac")
            else None
        )
        _ship_address_2=(
            self.ship_address_2
            if hasattr(self, "ship_address_2")
            else None
        )
        _master_loc_id=(
            self.master_loc_id
            if hasattr(self, "master_loc_id")
            else None
        )
        _street_address=(
            self.street_address
            if hasattr(self, "street_address")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _ext=(
            self.ext
            if hasattr(self, "ext")
            else None
        )
        _amenities=(
            self.amenities
            if hasattr(self, "amenities")
            else None
        )
        _total_number_of_deals=(
            self.total_number_of_deals
            if hasattr(self, "total_number_of_deals")
            else None
        )
        _total_number_of_ratings=(
            self.total_number_of_ratings
            if hasattr(self, "total_number_of_ratings")
            else None
        )
        _average_rating=(
            self.average_rating
            if hasattr(self, "average_rating")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"business_id={_business_id!r}, "
            f"site_id={_site_id!r}, "
            f"business_description={_business_description!r}, "
            f"additional_image_ur_ls={_additional_image_ur_ls!r}, "
            f"facility_square_feet={_facility_square_feet!r}, "
            f"pro_spa_finder_site={_pro_spa_finder_site!r}, "
            f"has_classes={_has_classes!r}, "
            f"phone_extension={_phone_extension!r}, "
            f"action={_action!r}, "
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"address={_address!r}, "
            f"address_2={_address_2!r}, "
            f"tax_1={_tax_1!r}, "
            f"tax_2={_tax_2!r}, "
            f"tax_3={_tax_3!r}, "
            f"tax_4={_tax_4!r}, "
            f"tax_5={_tax_5!r}, "
            f"phone={_phone!r}, "
            f"city={_city!r}, "
            f"state_prov_code={_state_prov_code!r}, "
            f"postal_code={_postal_code!r}, "
            f"latitude={_latitude!r}, "
            f"longitude={_longitude!r}, "
            f"distance_in_miles={_distance_in_miles!r}, "
            f"image_url={_image_url!r}, "
            f"description={_description!r}, "
            f"has_site={_has_site!r}, "
            f"can_book={_can_book!r}, "
            f"number_treatment_rooms={_number_treatment_rooms!r}, "
            f"active={_active!r}, "
            f"inv_active={_inv_active!r}, "
            f"ws_show={_ws_show!r}, "
            f"email={_email!r}, "
            f"contact_name={_contact_name!r}, "
            f"ship_address={_ship_address!r}, "
            f"ship_state={_ship_state!r}, "
            f"ship_postal={_ship_postal!r}, "
            f"ship_phone={_ship_phone!r}, "
            f"ship_poc={_ship_poc!r}, "
            f"tax_grouping={_tax_grouping!r}, "
            f"label_tax_1={_label_tax_1!r}, "
            f"label_tax_2={_label_tax_2!r}, "
            f"label_tax_3={_label_tax_3!r}, "
            f"label_tax_4={_label_tax_4!r}, "
            f"label_tax_5={_label_tax_5!r}, "
            f"wac={_wac!r}, "
            f"ship_address_2={_ship_address_2!r}, "
            f"master_loc_id={_master_loc_id!r}, "
            f"street_address={_street_address!r}, "
            f"country={_country!r}, "
            f"ext={_ext!r}, "
            f"amenities={_amenities!r}, "
            f"total_number_of_deals={_total_number_of_deals!r}, "
            f"total_number_of_ratings={_total_number_of_ratings!r}, "
            f"average_rating={_average_rating!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _business_id=(
            self.business_id
            if hasattr(self, "business_id")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _business_description=(
            self.business_description
            if hasattr(self, "business_description")
            else None
        )
        _additional_image_ur_ls=(
            self.additional_image_ur_ls
            if hasattr(self, "additional_image_ur_ls")
            else None
        )
        _facility_square_feet=(
            self.facility_square_feet
            if hasattr(self, "facility_square_feet")
            else None
        )
        _pro_spa_finder_site=(
            self.pro_spa_finder_site
            if hasattr(self, "pro_spa_finder_site")
            else None
        )
        _has_classes=(
            self.has_classes
            if hasattr(self, "has_classes")
            else None
        )
        _phone_extension=(
            self.phone_extension
            if hasattr(self, "phone_extension")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _tax_1=(
            self.tax_1
            if hasattr(self, "tax_1")
            else None
        )
        _tax_2=(
            self.tax_2
            if hasattr(self, "tax_2")
            else None
        )
        _tax_3=(
            self.tax_3
            if hasattr(self, "tax_3")
            else None
        )
        _tax_4=(
            self.tax_4
            if hasattr(self, "tax_4")
            else None
        )
        _tax_5=(
            self.tax_5
            if hasattr(self, "tax_5")
            else None
        )
        _phone=(
            self.phone
            if hasattr(self, "phone")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _state_prov_code=(
            self.state_prov_code
            if hasattr(self, "state_prov_code")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _latitude=(
            self.latitude
            if hasattr(self, "latitude")
            else None
        )
        _longitude=(
            self.longitude
            if hasattr(self, "longitude")
            else None
        )
        _distance_in_miles=(
            self.distance_in_miles
            if hasattr(self, "distance_in_miles")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _has_site=(
            self.has_site
            if hasattr(self, "has_site")
            else None
        )
        _can_book=(
            self.can_book
            if hasattr(self, "can_book")
            else None
        )
        _number_treatment_rooms=(
            self.number_treatment_rooms
            if hasattr(self, "number_treatment_rooms")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _inv_active=(
            self.inv_active
            if hasattr(self, "inv_active")
            else None
        )
        _ws_show=(
            self.ws_show
            if hasattr(self, "ws_show")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _ship_address=(
            self.ship_address
            if hasattr(self, "ship_address")
            else None
        )
        _ship_state=(
            self.ship_state
            if hasattr(self, "ship_state")
            else None
        )
        _ship_postal=(
            self.ship_postal
            if hasattr(self, "ship_postal")
            else None
        )
        _ship_phone=(
            self.ship_phone
            if hasattr(self, "ship_phone")
            else None
        )
        _ship_poc=(
            self.ship_poc
            if hasattr(self, "ship_poc")
            else None
        )
        _tax_grouping=(
            self.tax_grouping
            if hasattr(self, "tax_grouping")
            else None
        )
        _label_tax_1=(
            self.label_tax_1
            if hasattr(self, "label_tax_1")
            else None
        )
        _label_tax_2=(
            self.label_tax_2
            if hasattr(self, "label_tax_2")
            else None
        )
        _label_tax_3=(
            self.label_tax_3
            if hasattr(self, "label_tax_3")
            else None
        )
        _label_tax_4=(
            self.label_tax_4
            if hasattr(self, "label_tax_4")
            else None
        )
        _label_tax_5=(
            self.label_tax_5
            if hasattr(self, "label_tax_5")
            else None
        )
        _wac=(
            self.wac
            if hasattr(self, "wac")
            else None
        )
        _ship_address_2=(
            self.ship_address_2
            if hasattr(self, "ship_address_2")
            else None
        )
        _master_loc_id=(
            self.master_loc_id
            if hasattr(self, "master_loc_id")
            else None
        )
        _street_address=(
            self.street_address
            if hasattr(self, "street_address")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _ext=(
            self.ext
            if hasattr(self, "ext")
            else None
        )
        _amenities=(
            self.amenities
            if hasattr(self, "amenities")
            else None
        )
        _total_number_of_deals=(
            self.total_number_of_deals
            if hasattr(self, "total_number_of_deals")
            else None
        )
        _total_number_of_ratings=(
            self.total_number_of_ratings
            if hasattr(self, "total_number_of_ratings")
            else None
        )
        _average_rating=(
            self.average_rating
            if hasattr(self, "average_rating")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"business_id={_business_id!s}, "
            f"site_id={_site_id!s}, "
            f"business_description={_business_description!s}, "
            f"additional_image_ur_ls={_additional_image_ur_ls!s}, "
            f"facility_square_feet={_facility_square_feet!s}, "
            f"pro_spa_finder_site={_pro_spa_finder_site!s}, "
            f"has_classes={_has_classes!s}, "
            f"phone_extension={_phone_extension!s}, "
            f"action={_action!s}, "
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"address={_address!s}, "
            f"address_2={_address_2!s}, "
            f"tax_1={_tax_1!s}, "
            f"tax_2={_tax_2!s}, "
            f"tax_3={_tax_3!s}, "
            f"tax_4={_tax_4!s}, "
            f"tax_5={_tax_5!s}, "
            f"phone={_phone!s}, "
            f"city={_city!s}, "
            f"state_prov_code={_state_prov_code!s}, "
            f"postal_code={_postal_code!s}, "
            f"latitude={_latitude!s}, "
            f"longitude={_longitude!s}, "
            f"distance_in_miles={_distance_in_miles!s}, "
            f"image_url={_image_url!s}, "
            f"description={_description!s}, "
            f"has_site={_has_site!s}, "
            f"can_book={_can_book!s}, "
            f"number_treatment_rooms={_number_treatment_rooms!s}, "
            f"active={_active!s}, "
            f"inv_active={_inv_active!s}, "
            f"ws_show={_ws_show!s}, "
            f"email={_email!s}, "
            f"contact_name={_contact_name!s}, "
            f"ship_address={_ship_address!s}, "
            f"ship_state={_ship_state!s}, "
            f"ship_postal={_ship_postal!s}, "
            f"ship_phone={_ship_phone!s}, "
            f"ship_poc={_ship_poc!s}, "
            f"tax_grouping={_tax_grouping!s}, "
            f"label_tax_1={_label_tax_1!s}, "
            f"label_tax_2={_label_tax_2!s}, "
            f"label_tax_3={_label_tax_3!s}, "
            f"label_tax_4={_label_tax_4!s}, "
            f"label_tax_5={_label_tax_5!s}, "
            f"wac={_wac!s}, "
            f"ship_address_2={_ship_address_2!s}, "
            f"master_loc_id={_master_loc_id!s}, "
            f"street_address={_street_address!s}, "
            f"country={_country!s}, "
            f"ext={_ext!s}, "
            f"amenities={_amenities!s}, "
            f"total_number_of_deals={_total_number_of_deals!s}, "
            f"total_number_of_ratings={_total_number_of_ratings!s}, "
            f"average_rating={_average_rating!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)


class PricingOptionController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize PricingOptionController object."""
        super(PricingOptionController, self).__init__(config)

    def update_pricing_option(self,
                              version,
                              request,
                              site_id,
                              authorization=None):
        """Perform a POST request to
        /public/v{version}/pricingoption/updatepricingoption.

        Update Pricing Option data such as name, details, price, discontinued using
        PricingOptionId(product id)

        Args:
            version (str): version of the api.
            request (UpdatePricingOptionRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            Any: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/pricingoption/updatepricingoption")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.add_appointment_request import (
    AddAppointmentRequest,
)
from mindbodypublicapi.models.api_error import (
    ApiError,
)
from mindbodypublicapi.models.appointment import (
    Appointment,
)


class AddAppointmentOutcome(object):
    """Implementation of the 'AddAppointmentOutcome' model.

    Contains information about an appointment creation outcome.

    Attributes:
        appointment (Appointment): Contains information about an appointment.
        error (ApiError): The model property of type ApiError.
        request (AddAppointmentRequest): Represents a request to add a new
            appointment, including details such as client information, appointment
            timing, location, and additional preferences.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "appointment": "Appointment",
        "error": "Error",
        "request": "Request",
    }

    _optionals = [
        "appointment",
        "error",
        "request",
    ]

    def __init__(
        self,
        appointment=APIHelper.SKIP,
        error=APIHelper.SKIP,
        request=APIHelper.SKIP):
        """Initialize a AddAppointmentOutcome instance."""
        # Initialize members of the class
        if appointment is not APIHelper.SKIP:
            self.appointment = appointment
        if error is not APIHelper.SKIP:
            self.error = error
        if request is not APIHelper.SKIP:
            self.request = request

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        appointment =\
            Appointment.from_dictionary(
                dictionary.get("Appointment"))\
                if "Appointment" in dictionary.keys()\
                else APIHelper.SKIP
        error =\
            ApiError.from_dictionary(
                dictionary.get("Error"))\
                if "Error" in dictionary.keys()\
                else APIHelper.SKIP
        request =\
            AddAppointmentRequest.from_dictionary(
                dictionary.get("Request"))\
                if "Request" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(appointment,
                   error,
                   request)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _appointment=(
            self.appointment
            if hasattr(self, "appointment")
            else None
        )
        _error=(
            self.error
            if hasattr(self, "error")
            else None
        )
        _request=(
            self.request
            if hasattr(self, "request")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment={_appointment!r}, "
            f"error={_error!r}, "
            f"request={_request!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _appointment=(
            self.appointment
            if hasattr(self, "appointment")
            else None
        )
        _error=(
            self.error
            if hasattr(self, "error")
            else None
        )
        _request=(
            self.request
            if hasattr(self, "request")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment={_appointment!s}, "
            f"error={_error!s}, "
            f"request={_request!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ClientCreditCard(object):
    """Implementation of the 'ClientCreditCard' model.

    A client credit card.

    Attributes:
        address (str): The billing address for the credit card.
        card_holder (str): The name of the card holder.
        card_number (str): The credit card number.
        card_type (str): The type of credit card, for example Visa or MasterCard.
        city (str): The city in which the billing address is located.
        exp_month (str): The month in which the credit card expires.
        exp_year (str): The year in which the credit card expires.
        last_four (str): The last four digits of the credit card number.
        postal_code (str): The postal code where the billing address is located.
        state (str): The state that the billing address is located in.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": "Address",
        "card_holder": "CardHolder",
        "card_number": "CardNumber",
        "card_type": "CardType",
        "city": "City",
        "exp_month": "ExpMonth",
        "exp_year": "ExpYear",
        "last_four": "LastFour",
        "postal_code": "PostalCode",
        "state": "State",
    }

    _optionals = [
        "address",
        "card_holder",
        "card_number",
        "card_type",
        "city",
        "exp_month",
        "exp_year",
        "last_four",
        "postal_code",
        "state",
    ]

    def __init__(
        self,
        address=APIHelper.SKIP,
        card_holder=APIHelper.SKIP,
        card_number=APIHelper.SKIP,
        card_type=APIHelper.SKIP,
        city=APIHelper.SKIP,
        exp_month=APIHelper.SKIP,
        exp_year=APIHelper.SKIP,
        last_four=APIHelper.SKIP,
        postal_code=APIHelper.SKIP,
        state=APIHelper.SKIP):
        """Initialize a ClientCreditCard instance."""
        # Initialize members of the class
        if address is not APIHelper.SKIP:
            self.address = address
        if card_holder is not APIHelper.SKIP:
            self.card_holder = card_holder
        if card_number is not APIHelper.SKIP:
            self.card_number = card_number
        if card_type is not APIHelper.SKIP:
            self.card_type = card_type
        if city is not APIHelper.SKIP:
            self.city = city
        if exp_month is not APIHelper.SKIP:
            self.exp_month = exp_month
        if exp_year is not APIHelper.SKIP:
            self.exp_year = exp_year
        if last_four is not APIHelper.SKIP:
            self.last_four = last_four
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code
        if state is not APIHelper.SKIP:
            self.state = state

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        address =\
            dictionary.get("Address")\
            if dictionary.get("Address")\
                else APIHelper.SKIP
        card_holder =\
            dictionary.get("CardHolder")\
            if dictionary.get("CardHolder")\
                else APIHelper.SKIP
        card_number =\
            dictionary.get("CardNumber")\
            if dictionary.get("CardNumber")\
                else APIHelper.SKIP
        card_type =\
            dictionary.get("CardType")\
            if dictionary.get("CardType")\
                else APIHelper.SKIP
        city =\
            dictionary.get("City")\
            if dictionary.get("City")\
                else APIHelper.SKIP
        exp_month =\
            dictionary.get("ExpMonth")\
            if dictionary.get("ExpMonth")\
                else APIHelper.SKIP
        exp_year =\
            dictionary.get("ExpYear")\
            if dictionary.get("ExpYear")\
                else APIHelper.SKIP
        last_four =\
            dictionary.get("LastFour")\
            if dictionary.get("LastFour")\
                else APIHelper.SKIP
        postal_code =\
            dictionary.get("PostalCode")\
            if dictionary.get("PostalCode")\
                else APIHelper.SKIP
        state =\
            dictionary.get("State")\
            if dictionary.get("State")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(address,
                   card_holder,
                   card_number,
                   card_type,
                   city,
                   exp_month,
                   exp_year,
                   last_four,
                   postal_code,
                   state)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _card_holder=(
            self.card_holder
            if hasattr(self, "card_holder")
            else None
        )
        _card_number=(
            self.card_number
            if hasattr(self, "card_number")
            else None
        )
        _card_type=(
            self.card_type
            if hasattr(self, "card_type")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _exp_month=(
            self.exp_month
            if hasattr(self, "exp_month")
            else None
        )
        _exp_year=(
            self.exp_year
            if hasattr(self, "exp_year")
            else None
        )
        _last_four=(
            self.last_four
            if hasattr(self, "last_four")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"address={_address!r}, "
            f"card_holder={_card_holder!r}, "
            f"card_number={_card_number!r}, "
            f"card_type={_card_type!r}, "
            f"city={_city!r}, "
            f"exp_month={_exp_month!r}, "
            f"exp_year={_exp_year!r}, "
            f"last_four={_last_four!r}, "
            f"postal_code={_postal_code!r}, "
            f"state={_state!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _card_holder=(
            self.card_holder
            if hasattr(self, "card_holder")
            else None
        )
        _card_number=(
            self.card_number
            if hasattr(self, "card_number")
            else None
        )
        _card_type=(
            self.card_type
            if hasattr(self, "card_type")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _exp_month=(
            self.exp_month
            if hasattr(self, "exp_month")
            else None
        )
        _exp_year=(
            self.exp_year
            if hasattr(self, "exp_year")
            else None
        )
        _last_four=(
            self.last_four
            if hasattr(self, "last_four")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"address={_address!s}, "
            f"card_holder={_card_holder!s}, "
            f"card_number={_card_number!s}, "
            f"card_type={_card_type!s}, "
            f"city={_city!s}, "
            f"exp_month={_exp_month!s}, "
            f"exp_year={_exp_year!s}, "
            f"last_four={_last_four!s}, "
            f"postal_code={_postal_code!s}, "
            f"state={_state!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetGiftCardBalanceResponse(object):
    """Implementation of the 'GetGiftCardBalanceResponse' model.

    Attributes:
        barcode_id (str): The gift card's barcode ID.
        remaining_balance (float): The gift card's remaining balance.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "barcode_id": "BarcodeId",
        "remaining_balance": "RemainingBalance",
    }

    _optionals = [
        "barcode_id",
        "remaining_balance",
    ]

    def __init__(
        self,
        barcode_id=APIHelper.SKIP,
        remaining_balance=APIHelper.SKIP):
        """Initialize a GetGiftCardBalanceResponse instance."""
        # Initialize members of the class
        if barcode_id is not APIHelper.SKIP:
            self.barcode_id = barcode_id
        if remaining_balance is not APIHelper.SKIP:
            self.remaining_balance = remaining_balance

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        barcode_id =\
            dictionary.get("BarcodeId")\
            if dictionary.get("BarcodeId")\
                else APIHelper.SKIP
        remaining_balance =\
            dictionary.get("RemainingBalance")\
            if dictionary.get("RemainingBalance")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(barcode_id,
                   remaining_balance)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _remaining_balance=(
            self.remaining_balance
            if hasattr(self, "remaining_balance")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"barcode_id={_barcode_id!r}, "
            f"remaining_balance={_remaining_balance!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _remaining_balance=(
            self.remaining_balance
            if hasattr(self, "remaining_balance")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"barcode_id={_barcode_id!s}, "
            f"remaining_balance={_remaining_balance!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddAppointmentAddOnResponse(object):
    """Implementation of the 'AddAppointmentAddOnResponse' model.

    Attributes:
        appointment_id (int): This is the id of the main appointment we added on to
        add_on_appointment_id (int): This is the id for the newly created add-on
            appointment

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "appointment_id": "AppointmentId",
        "add_on_appointment_id": "AddOnAppointmentId",
    }

    _optionals = [
        "appointment_id",
        "add_on_appointment_id",
    ]

    def __init__(
        self,
        appointment_id=APIHelper.SKIP,
        add_on_appointment_id=APIHelper.SKIP):
        """Initialize a AddAppointmentAddOnResponse instance."""
        # Initialize members of the class
        if appointment_id is not APIHelper.SKIP:
            self.appointment_id = appointment_id
        if add_on_appointment_id is not APIHelper.SKIP:
            self.add_on_appointment_id = add_on_appointment_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        appointment_id =\
            dictionary.get("AppointmentId")\
            if dictionary.get("AppointmentId")\
                else APIHelper.SKIP
        add_on_appointment_id =\
            dictionary.get("AddOnAppointmentId")\
            if dictionary.get("AddOnAppointmentId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(appointment_id,
                   add_on_appointment_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _add_on_appointment_id=(
            self.add_on_appointment_id
            if hasattr(self, "add_on_appointment_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!r}, "
            f"add_on_appointment_id={_add_on_appointment_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _add_on_appointment_id=(
            self.add_on_appointment_id
            if hasattr(self, "add_on_appointment_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!s}, "
            f"add_on_appointment_id={_add_on_appointment_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetProductsRequest(object):
    """Implementation of the 'GetProductsRequest' model.

    Represents a request to get products with optional filters.

    Attributes:
        product_ids (List[str]): The barcode number of the product to be filter by.
        search_text (str): A search filter, used for searching by term.
        category_ids (List[int]): A list of revenue category IDs to filter by. Use
            this ID when calling the GET Categories endpoint.
        sub_category_ids (List[int]): A list of subcategory IDs to filter by. Use
            this ID when calling the GET Categories endpoint.
        secondary_category_ids (List[int]): A list of secondary categories to filter
            by. Use this ID when calling the GET Categories endpoint.
        sell_online (bool): When `true`, only products that can be sold online are
            returned.<br />  When `false`, all products are returned.<br />  Default:
            **false**
        location_id (int): The location ID to use to determine the tax for the
            products that this request returns.<br />  Default: **online store**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_ids": "ProductIds",
        "search_text": "SearchText",
        "category_ids": "CategoryIds",
        "sub_category_ids": "SubCategoryIds",
        "secondary_category_ids": "SecondaryCategoryIds",
        "sell_online": "SellOnline",
        "location_id": "LocationId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "product_ids",
        "search_text",
        "category_ids",
        "sub_category_ids",
        "secondary_category_ids",
        "sell_online",
        "location_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        product_ids=APIHelper.SKIP,
        search_text=APIHelper.SKIP,
        category_ids=APIHelper.SKIP,
        sub_category_ids=APIHelper.SKIP,
        secondary_category_ids=APIHelper.SKIP,
        sell_online=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetProductsRequest instance."""
        # Initialize members of the class
        if product_ids is not APIHelper.SKIP:
            self.product_ids = product_ids
        if search_text is not APIHelper.SKIP:
            self.search_text = search_text
        if category_ids is not APIHelper.SKIP:
            self.category_ids = category_ids
        if sub_category_ids is not APIHelper.SKIP:
            self.sub_category_ids = sub_category_ids
        if secondary_category_ids is not APIHelper.SKIP:
            self.secondary_category_ids = secondary_category_ids
        if sell_online is not APIHelper.SKIP:
            self.sell_online = sell_online
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        product_ids =\
            dictionary.get("ProductIds")\
            if dictionary.get("ProductIds")\
                else APIHelper.SKIP
        search_text =\
            dictionary.get("SearchText")\
            if dictionary.get("SearchText")\
                else APIHelper.SKIP
        category_ids =\
            dictionary.get("CategoryIds")\
            if dictionary.get("CategoryIds")\
                else APIHelper.SKIP
        sub_category_ids =\
            dictionary.get("SubCategoryIds")\
            if dictionary.get("SubCategoryIds")\
                else APIHelper.SKIP
        secondary_category_ids =\
            dictionary.get("SecondaryCategoryIds")\
            if dictionary.get("SecondaryCategoryIds")\
                else APIHelper.SKIP
        sell_online =\
            dictionary.get("SellOnline")\
            if "SellOnline" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(product_ids,
                   search_text,
                   category_ids,
                   sub_category_ids,
                   secondary_category_ids,
                   sell_online,
                   location_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _product_ids=(
            self.product_ids
            if hasattr(self, "product_ids")
            else None
        )
        _search_text=(
            self.search_text
            if hasattr(self, "search_text")
            else None
        )
        _category_ids=(
            self.category_ids
            if hasattr(self, "category_ids")
            else None
        )
        _sub_category_ids=(
            self.sub_category_ids
            if hasattr(self, "sub_category_ids")
            else None
        )
        _secondary_category_ids=(
            self.secondary_category_ids
            if hasattr(self, "secondary_category_ids")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_ids={_product_ids!r}, "
            f"search_text={_search_text!r}, "
            f"category_ids={_category_ids!r}, "
            f"sub_category_ids={_sub_category_ids!r}, "
            f"secondary_category_ids={_secondary_category_ids!r}, "
            f"sell_online={_sell_online!r}, "
            f"location_id={_location_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _product_ids=(
            self.product_ids
            if hasattr(self, "product_ids")
            else None
        )
        _search_text=(
            self.search_text
            if hasattr(self, "search_text")
            else None
        )
        _category_ids=(
            self.category_ids
            if hasattr(self, "category_ids")
            else None
        )
        _sub_category_ids=(
            self.sub_category_ids
            if hasattr(self, "sub_category_ids")
            else None
        )
        _secondary_category_ids=(
            self.secondary_category_ids
            if hasattr(self, "secondary_category_ids")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_ids={_product_ids!s}, "
            f"search_text={_search_text!s}, "
            f"category_ids={_category_ids!s}, "
            f"sub_category_ids={_sub_category_ids!s}, "
            f"secondary_category_ids={_secondary_category_ids!s}, "
            f"sell_online={_sell_online!s}, "
            f"location_id={_location_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddClientToEnrollmentRequest(object):
    """Implementation of the 'AddClientToEnrollmentRequest' model.

    Add Client To Enrollment Request Model

    Attributes:
        client_id (str): The client IDs of the clients to add to the specified
            enrollments.
        class_schedule_id (int): The class schedule IDs of the enrollments to add the
            clients to. The ClassScheduleId can be found in GetEnrollments as the
            EnrollmentId.
        enroll_date_forward (datetime): Enroll the clients from this date forward.
            `EnrollDateForward` takes priority over open enrollment.  Default:
            **null**
        enroll_open (List[datetime]): Enroll for selected dates.
        test (bool): When `true`, input information is validated, but not
            committed.<br />  Default: **false**
        send_email (bool): When `true`, indicates that the client should be sent an
            email. An email is only sent if the client has an email address and
            automatic emails have been set up. <br />  Default: **false**
        waitlist (bool): When `true`, the client is added to a specific enrollments
            waiting list.  Default: **false**
        waitlist_entry_id (int): The waiting list entry to add. Used to add a client
            to an enrollment from a waiting list entry.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "class_schedule_id": "ClassScheduleId",
        "enroll_date_forward": "EnrollDateForward",
        "enroll_open": "EnrollOpen",
        "test": "Test",
        "send_email": "SendEmail",
        "waitlist": "Waitlist",
        "waitlist_entry_id": "WaitlistEntryId",
    }

    _optionals = [
        "enroll_date_forward",
        "enroll_open",
        "test",
        "send_email",
        "waitlist",
        "waitlist_entry_id",
    ]

    def __init__(
        self,
        client_id=None,
        class_schedule_id=None,
        enroll_date_forward=APIHelper.SKIP,
        enroll_open=APIHelper.SKIP,
        test=APIHelper.SKIP,
        send_email=APIHelper.SKIP,
        waitlist=APIHelper.SKIP,
        waitlist_entry_id=APIHelper.SKIP):
        """Initialize a AddClientToEnrollmentRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.class_schedule_id = class_schedule_id
        if enroll_date_forward is not APIHelper.SKIP:
            self.enroll_date_forward =\
                 APIHelper.apply_datetime_converter(
                enroll_date_forward, APIHelper.RFC3339DateTime)\
                 if enroll_date_forward else None
        if enroll_open is not None and enroll_open is not APIHelper.SKIP:
            self.enroll_open = APIHelper.apply_datetime_converter(
                enroll_open, APIHelper.RFC3339DateTime)
        if test is not APIHelper.SKIP:
            self.test = test
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email
        if waitlist is not APIHelper.SKIP:
            self.waitlist = waitlist
        if waitlist_entry_id is not APIHelper.SKIP:
            self.waitlist_entry_id = waitlist_entry_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        class_schedule_id =\
            dictionary.get("ClassScheduleId")\
            if dictionary.get("ClassScheduleId")\
                else None
        enroll_date_forward = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EnrollDateForward")).datetime\
            if dictionary.get("EnrollDateForward") else APIHelper.SKIP
        enroll_open = None
        if dictionary.get("EnrollOpen") is not None:
            enroll_open = list()
            for x in dictionary.get("EnrollOpen"):
                enroll_open.append(APIHelper.RFC3339DateTime.from_value(x).datetime)
        else:
            enroll_open = APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP
        waitlist =\
            dictionary.get("Waitlist")\
            if "Waitlist" in dictionary.keys()\
                else APIHelper.SKIP
        waitlist_entry_id =\
            dictionary.get("WaitlistEntryId")\
            if dictionary.get("WaitlistEntryId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   class_schedule_id,
                   enroll_date_forward,
                   enroll_open,
                   test,
                   send_email,
                   waitlist,
                   waitlist_entry_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _class_schedule_id=self.class_schedule_id
        _enroll_date_forward=(
            self.enroll_date_forward
            if hasattr(self, "enroll_date_forward")
            else None
        )
        _enroll_open=(
            self.enroll_open
            if hasattr(self, "enroll_open")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _waitlist=(
            self.waitlist
            if hasattr(self, "waitlist")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"class_schedule_id={_class_schedule_id!r}, "
            f"enroll_date_forward={_enroll_date_forward!r}, "
            f"enroll_open={_enroll_open!r}, "
            f"test={_test!r}, "
            f"send_email={_send_email!r}, "
            f"waitlist={_waitlist!r}, "
            f"waitlist_entry_id={_waitlist_entry_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _class_schedule_id=self.class_schedule_id
        _enroll_date_forward=(
            self.enroll_date_forward
            if hasattr(self, "enroll_date_forward")
            else None
        )
        _enroll_open=(
            self.enroll_open
            if hasattr(self, "enroll_open")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _waitlist=(
            self.waitlist
            if hasattr(self, "waitlist")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"class_schedule_id={_class_schedule_id!s}, "
            f"enroll_date_forward={_enroll_date_forward!s}, "
            f"enroll_open={_enroll_open!s}, "
            f"test={_test!s}, "
            f"send_email={_send_email!s}, "
            f"waitlist={_waitlist!s}, "
            f"waitlist_entry_id={_waitlist_entry_id!s}, "
            f")"
        )



# ruff: noqa: D104 | Missing docstring in public package
# ruff: noqa: RUF022 | `__all__` is not sorted
__all__ = [
    "api_helper",
    "configuration",
    "controllers",
    "exceptions",
    "http",
    "mindbodypublicapi_client",
    "models",
    "utilities",
]



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.user import User


class IssueResponse(object):
    """Implementation of the 'IssueResponse' model.

    POST UserToken/Issue successful response

    Attributes:
        token_type (str): The model property of type str.
        access_token (str): The authentication token value.
        expires (datetime): Token expiration in UTC.
        user (User): The model property of type User.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "token_type": "TokenType",
        "access_token": "AccessToken",
        "expires": "Expires",
        "user": "User",
    }

    _optionals = [
        "token_type",
        "access_token",
        "expires",
        "user",
    ]

    def __init__(
        self,
        token_type=APIHelper.SKIP,
        access_token=APIHelper.SKIP,
        expires=APIHelper.SKIP,
        user=APIHelper.SKIP):
        """Initialize a IssueResponse instance."""
        # Initialize members of the class
        if token_type is not APIHelper.SKIP:
            self.token_type = token_type
        if access_token is not APIHelper.SKIP:
            self.access_token = access_token
        if expires is not APIHelper.SKIP:
            self.expires =\
                 APIHelper.apply_datetime_converter(
                expires, APIHelper.RFC3339DateTime)\
                 if expires else None
        if user is not APIHelper.SKIP:
            self.user = user

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        token_type =\
            dictionary.get("TokenType")\
            if dictionary.get("TokenType")\
                else APIHelper.SKIP
        access_token =\
            dictionary.get("AccessToken")\
            if dictionary.get("AccessToken")\
                else APIHelper.SKIP
        expires = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("Expires")).datetime\
            if dictionary.get("Expires") else APIHelper.SKIP
        user =\
            User.from_dictionary(
                dictionary.get("User"))\
                if "User" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(token_type,
                   access_token,
                   expires,
                   user)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _token_type=(
            self.token_type
            if hasattr(self, "token_type")
            else None
        )
        _access_token=(
            self.access_token
            if hasattr(self, "access_token")
            else None
        )
        _expires=(
            self.expires
            if hasattr(self, "expires")
            else None
        )
        _user=(
            self.user
            if hasattr(self, "user")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"token_type={_token_type!r}, "
            f"access_token={_access_token!r}, "
            f"expires={_expires!r}, "
            f"user={_user!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _token_type=(
            self.token_type
            if hasattr(self, "token_type")
            else None
        )
        _access_token=(
            self.access_token
            if hasattr(self, "access_token")
            else None
        )
        _expires=(
            self.expires
            if hasattr(self, "expires")
            else None
        )
        _user=(
            self.user
            if hasattr(self, "user")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"token_type={_token_type!s}, "
            f"access_token={_access_token!s}, "
            f"expires={_expires!s}, "
            f"user={_user!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class RemoveFromWaitlistRequest(object):
    """Implementation of the 'RemoveFromWaitlistRequest' model.

    Attributes:
        waitlist_entry_ids (List[int]): A list of `WaitlistEntryIds` to remove from
            the waiting list.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "waitlist_entry_ids": "WaitlistEntryIds",
    }

    def __init__(
        self,
        waitlist_entry_ids=None):
        """Initialize a RemoveFromWaitlistRequest instance."""
        # Initialize members of the class
        self.waitlist_entry_ids = waitlist_entry_ids

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        waitlist_entry_ids =\
            dictionary.get("WaitlistEntryIds")\
            if dictionary.get("WaitlistEntryIds")\
                else None

        # Return an object of this model
        return cls(waitlist_entry_ids)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _waitlist_entry_ids=self.waitlist_entry_ids
        return (
            f"{self.__class__.__name__}("
            f"waitlist_entry_ids={_waitlist_entry_ids!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _waitlist_entry_ids=self.waitlist_entry_ids
        return (
            f"{self.__class__.__name__}("
            f"waitlist_entry_ids={_waitlist_entry_ids!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class ClientDocument(object):
    """Implementation of the 'ClientDocument' model.

    Attributes:
        file_name (str): The name of the file to be used on the client’s documents
            page when it is uploaded.
        media_type (str): The type of file or file extension. Possible values are:  *
            pdf  * jpg  * jpeg  * tif  * tiff  * png  * doc  * docx  * bmp  * txt  *
            rtf  * xlsx  * xls  * gif  * zip  * ppt  * pptx  * mov
        buffer (str): A Base64-encoded string representation of the file’s byte array.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "file_name": "FileName",
        "media_type": "MediaType",
        "buffer": "Buffer",
    }

    def __init__(
        self,
        file_name=None,
        media_type=None,
        buffer=None):
        """Initialize a ClientDocument instance."""
        # Initialize members of the class
        self.file_name = file_name
        self.media_type = media_type
        self.buffer = buffer

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        file_name =\
            dictionary.get("FileName")\
            if dictionary.get("FileName")\
                else None
        media_type =\
            dictionary.get("MediaType")\
            if dictionary.get("MediaType")\
                else None
        buffer =\
            dictionary.get("Buffer")\
            if dictionary.get("Buffer")\
                else None

        # Return an object of this model
        return cls(file_name,
                   media_type,
                   buffer)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _file_name=self.file_name
        _media_type=self.media_type
        _buffer=self.buffer
        return (
            f"{self.__class__.__name__}("
            f"file_name={_file_name!r}, "
            f"media_type={_media_type!r}, "
            f"buffer={_buffer!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _file_name=self.file_name
        _media_type=self.media_type
        _buffer=self.buffer
        return (
            f"{self.__class__.__name__}("
            f"file_name={_file_name!s}, "
            f"media_type={_media_type!s}, "
            f"buffer={_buffer!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.copy_credit_card_response_client import (
    CopyCreditCardResponseClient,
)


class CopyCreditCardResponse(object):
    """Implementation of the 'CopyCreditCardResponse' model.

    crosssite/copycreditcard

    Attributes:
        copied_from (CopyCreditCardResponseClient): The model property of type
            CopyCreditCardResponseClient.
        copied_to (CopyCreditCardResponseClient): The model property of type
            CopyCreditCardResponseClient.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "copied_from": "CopiedFrom",
        "copied_to": "CopiedTo",
    }

    _optionals = [
        "copied_from",
        "copied_to",
    ]

    def __init__(
        self,
        copied_from=APIHelper.SKIP,
        copied_to=APIHelper.SKIP):
        """Initialize a CopyCreditCardResponse instance."""
        # Initialize members of the class
        if copied_from is not APIHelper.SKIP:
            self.copied_from = copied_from
        if copied_to is not APIHelper.SKIP:
            self.copied_to = copied_to

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        copied_from =\
            CopyCreditCardResponseClient.from_dictionary(
                dictionary.get("CopiedFrom"))\
                if "CopiedFrom" in dictionary.keys()\
                else APIHelper.SKIP
        copied_to =\
            CopyCreditCardResponseClient.from_dictionary(
                dictionary.get("CopiedTo"))\
                if "CopiedTo" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(copied_from,
                   copied_to)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _copied_from=(
            self.copied_from
            if hasattr(self, "copied_from")
            else None
        )
        _copied_to=(
            self.copied_to
            if hasattr(self, "copied_to")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"copied_from={_copied_from!r}, "
            f"copied_to={_copied_to!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _copied_from=(
            self.copied_from
            if hasattr(self, "copied_from")
            else None
        )
        _copied_to=(
            self.copied_to
            if hasattr(self, "copied_to")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"copied_from={_copied_from!s}, "
            f"copied_to={_copied_to!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.add_promo_code_response import (
    AddPromoCodeResponse,
)
from mindbodypublicapi.models.add_site_client_index_response import (
    AddSiteClientIndexResponse,
)
from mindbodypublicapi.models.get_activation_code_response import (
    GetActivationCodeResponse,
)
from mindbodypublicapi.models.get_categories_response import (
    GetCategoriesResponse,
)
from mindbodypublicapi.models.get_genders_response import (
    GetGendersResponse,
)
from mindbodypublicapi.models.get_liability_waiver_response import (
    GetLiabilityWaiverResponse,
)
from mindbodypublicapi.models.get_locations_response import (
    GetLocationsResponse,
)
from mindbodypublicapi.models.get_memberships_response import (
    GetMembershipsResponse,
)
from mindbodypublicapi.models.get_mobile_providers_response import (
    GetMobileProvidersResponse,
)
from mindbodypublicapi.models.get_payment_types_response import (
    GetPaymentTypesResponse,
)
from mindbodypublicapi.models.get_programs_response import (
    GetProgramsResponse,
)
from mindbodypublicapi.models.get_promo_codes_response import (
    GetPromoCodesResponse,
)
from mindbodypublicapi.models.get_prospect_stages_response import (
    GetProspectStagesResponse,
)
from mindbodypublicapi.models.get_relationships_response import (
    GetRelationshipsResponse,
)
from mindbodypublicapi.models.get_resources_response import (
    GetResourcesResponse,
)
from mindbodypublicapi.models.get_session_types_response import (
    GetSessionTypesResponse,
)
from mindbodypublicapi.models.get_sites_response import (
    GetSitesResponse,
)
from mindbodypublicapi.models.update_site_client_index_response import (
    UpdateSiteClientIndexResponse,
)


class SiteController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize SiteController object."""
        super(SiteController, self).__init__(config)

    def get_activation_code(self,
                            version,
                            authorization=None):
        """Perform a GET request to /public/v{version}/site/activationcode.

        Before you can use this endpoint, MINDBODY must approve your developer
        account for live access. If you have finished testing in the sandbox and are
        ready to begin working with MINDBODY customers, log into your account and
        request to go live.
        See [Accessing Business Data From
        MINDBODY](https://developers.mindbodyonline.com/PublicDocumentation/V6#accessi
        ng-business-data) for more information about the activation code and how to
        use it.
        Once you are approved, this endpoint returns an activation code.This endpoint
        supports only one site per call.

        Args:
            version (str): version of the api.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetActivationCodeResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/activationcode")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetActivationCodeResponse.from_dictionary),
        ).execute()

    def get_categories(self,
                       version,
                       site_id,
                       authorization=None,
                       request_active=None,
                       request_category_ids=None,
                       request_limit=None,
                       request_offset=None,
                       request_service=None,
                       request_sub_category_ids=None):
        """Perform a GET request to /public/v{version}/site/categories.

        Gets the categories.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_active (bool, optional): When `true`, the response only contains
                categories which are activated.   When `false`, only deactivated
                categories are returned.  Default: **All Categories**
            request_category_ids (List[int], optional): When included, the response
                only contains details about the specified category Ids.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_service (bool, optional): When `true`, the response only contains
                details about Revenue Categories.  When `false`, only Product Revenue
                Categories are returned.  Default: **All Categories**
            request_sub_category_ids (List[int], optional): When included, the
                response only contains details about the specified subcategory Ids.

        Returns:
            GetCategoriesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/categories")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.active")
                .value(request_active))
            .query_param(Parameter()
                .key("request.categoryIds")
                .value(request_category_ids))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.service")
                .value(request_service))
            .query_param(Parameter()
                .key("request.subCategoryIds")
                .value(request_sub_category_ids))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetCategoriesResponse.from_dictionary),
        ).execute()

    def get_genders(self,
                    version,
                    site_id,
                    authorization=None):
        """Perform a GET request to /public/v{version}/site/genders.

        The endpoint returns a list of configured client gender options for a site.
        Custom gender options are assignable to client genders only. Currently,
        custom values returned from this endpoint cannot be used as input for other
        endpoints to specify the genders of staff or client preferences.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetGendersResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/genders")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetGendersResponse.from_dictionary),
        ).execute()

    def get_liability_waiver(self,
                             version,
                             site_id,
                             authorization=None):
        """Perform a GET request to /public/v{version}/site/liabilitywaiver.

        Gets Liability Waiver content at the specified business.
        This endpoint requires staff user credentials.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetLiabilityWaiverResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/liabilitywaiver")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetLiabilityWaiverResponse.from_dictionary),
        ).execute()

    def get_locations(self,
                      version,
                      site_id,
                      authorization=None,
                      request_limit=None,
                      request_offset=None):
        """Perform a GET request to /public/v{version}/site/locations.

        Get locations for a site.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.

        Returns:
            GetLocationsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/locations")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetLocationsResponse.from_dictionary),
        ).execute()

    def get_memberships(self,
                        version,
                        site_id,
                        authorization=None,
                        request_membership_ids=None):
        """Perform a GET request to /public/v{version}/site/memberships.

        Get the memberships at a site.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_membership_ids (List[int], optional): The requested membership
                IDs.<br />  Default: **all** IDs that the authenticated user’s access
                level allows.

        Returns:
            GetMembershipsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/memberships")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.membershipIds")
                .value(request_membership_ids))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetMembershipsResponse.from_dictionary),
        ).execute()

    def get_mobile_providers(self,
                             version,
                             site_id,
                             authorization=None,
                             request_active=None):
        """Perform a GET request to /public/v{version}/site/mobileproviders.

        Get the list of mobile providers that are supported by the business.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_active (bool, optional): When `true`, the response only contains
                mobile providers which are activated.   When `false`, only
                deactivated mobile providers are returned.  Default: **All Mobile
                Providers**

        Returns:
            GetMobileProvidersResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/mobileproviders")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.active")
                .value(request_active))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetMobileProvidersResponse.from_dictionary),
        ).execute()

    def get_payment_types(self,
                          version,
                          site_id,
                          authorization=None,
                          request_active=None):
        """Perform a GET request to /public/v{version}/site/paymenttypes.

        Get payment types for a site.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_active (bool, optional): When `true`, the response only contains
                payment types which are activated.  When `false`, only deactivated
                payment types are returned.  Default: **All Payment Types**

        Returns:
            GetPaymentTypesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/paymenttypes")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.active")
                .value(request_active))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetPaymentTypesResponse.from_dictionary),
        ).execute()

    def get_programs(self,
                     version,
                     site_id,
                     authorization=None,
                     request_limit=None,
                     request_offset=None,
                     request_online_only=None,
                     request_program_ids=None,
                     request_schedule_type=None):
        """Perform a GET request to /public/v{version}/site/programs.

        Get service categories offered at a site.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_online_only (bool, optional): If `true`, filters results to show
                only those programs that are shown online.<br />  If `false`, all
                programs are returned.<br />  Default: **false**
            request_program_ids (List[int], optional): Program Ids to filter for
            request_schedule_type (RequestScheduleTypeEnum, optional): A schedule
                type used to filter the returned results. Possible values are:  * All
                * Class  * Enrollment  * Appointment  * Resource  * Media  * Arrival

        Returns:
            GetProgramsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/programs")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.onlineOnly")
                .value(request_online_only))
            .query_param(Parameter()
                .key("request.programIds")
                .value(request_program_ids))
            .query_param(Parameter()
                .key("request.scheduleType")
                .value(request_schedule_type))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetProgramsResponse.from_dictionary),
        ).execute()

    def get_promo_codes(self,
                        version,
                        site_id,
                        authorization=None,
                        request_active_only=None,
                        request_end_date=None,
                        request_last_modified_date=None,
                        request_limit=None,
                        request_offset=None,
                        request_online_only=None,
                        request_start_date=None):
        """Perform a GET request to /public/v{version}/site/promocodes.

        Gets a list of promocodes at the specified business. This endpoint requires
        staff user credentials.
        This staff member should have enabled the Set up promotions / **Semester
        discounts** staff permission.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_active_only (bool, optional): If true, filters results to show
                only promocodes that are active. If **false**, all promocodes are
                returned.  Default: **true**
            request_end_date (datetime, optional): Filters results to promocodes that
                were activated before this date.
            request_last_modified_date (datetime, optional): Filters results to
                promocodes that were modified on or after this date.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_online_only (bool, optional): If `true`, filters results to show
                only promocodes that can be used for online sale.  If `false`, all
                promocodes are returned.  Default: **false**
            request_start_date (datetime, optional): Filters results to promocodes
                that were activated after this date.

        Returns:
            GetPromoCodesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/promocodes")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.activeOnly")
                .value(request_active_only))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.lastModifiedDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_last_modified_date)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.onlineOnly")
                .value(request_online_only))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetPromoCodesResponse.from_dictionary),
        ).execute()

    def get_prospect_stages(self,
                            version,
                            site_id,
                            authorization=None,
                            request_active=None):
        """Perform a GET request to /public/v{version}/site/prospectstages.

        Get the list of prospect stages that represent the prospect stage options for
        prospective clients.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_active (bool, optional): When `true`, the response only contains
                prospect stages which are activated.  When `false`, only deactivated
                prospect stages are returned.  Default: **All Prospect Stages**

        Returns:
            GetProspectStagesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/prospectstages")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.active")
                .value(request_active))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetProspectStagesResponse.from_dictionary),
        ).execute()

    def get_relationships(self,
                          version,
                          site_id,
                          authorization=None,
                          request_active=None,
                          request_limit=None,
                          request_offset=None):
        """Perform a GET request to /public/v{version}/site/relationships.

        This endpoint retrieves the business site relationships.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_active (bool, optional): When `true`, the response only contains
                relationships which are activated.  When `false`, only deactivated
                relationships are returned.  Default: **All Relationships**
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.

        Returns:
            GetRelationshipsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/relationships")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.active")
                .value(request_active))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetRelationshipsResponse.from_dictionary),
        ).execute()

    def get_resource_availabilities(self,
                                    version,
                                    site_id,
                                    authorization=None,
                                    request_end_date=None,
                                    request_limit=None,
                                    request_location_ids=None,
                                    request_offset=None,
                                    request_program_ids=None,
                                    request_resource_ids=None,
                                    request_schedule_types=None,
                                    request_start_date=None):
        """Perform a GET request to
        /public/v{version}/site/resourceavailabilities.

        Get resource availabilities used at a site.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date (datetime, optional): End date. If default, StartDate is
                used.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_ids (List[int], optional): Filter by location ids
                (optional)
            request_offset (int, optional): Page offset, defaults to 0.
            request_program_ids (List[int], optional): Filter by program ids
                (optional)
            request_resource_ids (List[int], optional): Filter on resourceIds
            request_schedule_types (List[RequestScheduleTypeEnum], optional): Filter
                by schedule types (optional)
            request_start_date (datetime, optional): Start time

        Returns:
            GetResourcesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/resourceavailabilities")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationIds")
                .value(request_location_ids))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.programIds")
                .value(request_program_ids))
            .query_param(Parameter()
                .key("request.resourceIds")
                .value(request_resource_ids))
            .query_param(Parameter()
                .key("request.scheduleTypes")
                .value(request_schedule_types))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetResourcesResponse.from_dictionary),
        ).execute()

    def get_resources(self,
                      version,
                      site_id,
                      authorization=None,
                      request_include_inactive=None,
                      request_limit=None,
                      request_location_ids=None,
                      request_offset=None,
                      request_program_ids=None,
                      request_resource_ids=None,
                      request_schedule_types=None):
        """Perform a GET request to /public/v{version}/site/resources.

        Get resources used at a site.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_include_inactive (bool, optional): Enable to include inactive
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_ids (List[int], optional): Filter by location ids
                (optional)
            request_offset (int, optional): Page offset, defaults to 0.
            request_program_ids (List[int], optional): Filter by program ids
                (optional)
            request_resource_ids (List[int], optional): Filter on resourceIds
            request_schedule_types (List[RequestScheduleTypeEnum], optional): Filter
                by schedule types (optional)

        Returns:
            Any: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/resources")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.includeInactive")
                .value(request_include_inactive))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationIds")
                .value(request_location_ids))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.programIds")
                .value(request_program_ids))
            .query_param(Parameter()
                .key("request.resourceIds")
                .value(request_resource_ids))
            .query_param(Parameter()
                .key("request.scheduleTypes")
                .value(request_schedule_types))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize),
        ).execute()

    def get_session_types(self,
                          version,
                          site_id,
                          authorization=None,
                          request_limit=None,
                          request_offset=None,
                          request_online_only=None,
                          request_program_i_ds=None):
        """Perform a GET request to /public/v{version}/site/sessiontypes.

        Get the session types used at a site.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_online_only (bool, optional): When `true`, indicates that only
                the session types that can be booked online should be returned.<br />
                Default: **false**
            request_program_i_ds (List[int], optional): Filters results to session
                types that belong to one of the given program IDs. If omitted, all
                program IDs return.

        Returns:
            GetSessionTypesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/sessiontypes")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.onlineOnly")
                .value(request_online_only))
            .query_param(Parameter()
                .key("request.programIDs")
                .value(request_program_i_ds))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetSessionTypesResponse.from_dictionary),
        ).execute()

    def get_sites(self,
                  version,
                  authorization=None,
                  request_include_lead_channels=None,
                  request_include_per_staff_pricing=None,
                  request_limit=None,
                  request_offset=None,
                  request_site_ids=None):
        """Perform a GET request to /public/v{version}/site/sites.

        Gets a list of sites that the developer has permission to view.
        * Passing in no `SiteIds` returns all sites that the developer has access to.
        * Passing in one `SiteIds` returns more detailed information about the
        specified site.
        Important Behavior Notice:
        When calling GetSites without specifying a SiteId, or when passing multiple
        SiteIds, the response will include only limited data for each site. This is
        expected behavior designed to help identify accessible sites without
        returning full site-level configuration details.
        To retrieve complete information for a specific site, please make a separate
        GetSites request using a single SiteId.
        This design helps reduce payload size for multi-site queries, but we
        recognize it may require additional requests when full detail is needed. If
        your integration depends on full site-level data, we recommend retrieving the
        list of site IDs first, then querying each one individually as needed.

        Args:
            version (str): version of the api.
            authorization (str, optional): A staff user authorization token.
            request_include_lead_channels (bool, optional): This is an optional
                parameter to get lead channels for a Site.
            request_include_per_staff_pricing (bool, optional): Include whether or
                not studios have per staff pricing enabled.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_site_ids (List[int], optional): List of the requested site IDs.
                When omitted, returns all sites that the source has access to.

        Returns:
            GetSitesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/sites")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.includeLeadChannels")
                .value(request_include_lead_channels))
            .query_param(Parameter()
                .key("request.includePerStaffPricing")
                .value(request_include_per_staff_pricing))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.siteIds")
                .value(request_site_ids))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetSitesResponse.from_dictionary),
        ).execute()

    def add_client_index(self,
                         version,
                         request,
                         site_id,
                         authorization=None):
        """Perform a POST request to /public/v{version}/site/addclientindex.

        Creates a new client index record at the specified business.
        This endpoint requires staff user credentials.

        Args:
            version (str): version of the api.
            request (AddSiteClientIndexRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AddSiteClientIndexResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/addclientindex")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AddSiteClientIndexResponse.from_dictionary),
        ).execute()

    def add_promo_code(self,
                       version,
                       request,
                       site_id,
                       authorization=None):
        """Perform a POST request to /public/v{version}/site/addpromocode.

        Creates a new promocode record at the specified business.
        This endpoint requires staff user credentials. This staff memeber should have
        enabled the **Set up promotions / Semester discounts** staff permission.

        Args:
            version (str): version of the api.
            request (AddPromoCodeRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AddPromoCodeResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/addpromocode")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AddPromoCodeResponse.from_dictionary),
        ).execute()

    def deactivate_promo_code(self,
                              version,
                              request,
                              site_id,
                              authorization=None):
        """Perform a POST request to
        /public/v{version}/site/deactivatepromocode.

        Deactivates an existing promocode record at the specified business.
        This endpoint requires staff user credentials. This staff memeber should have
        enabled the **Set up promotions / Semester discounts** staff permission.

        Args:
            version (str): version of the api.
            request (DeactivatePromoCodeRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            Any: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/deactivatepromocode")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize),
        ).execute()

    def update_client_index(self,
                            version,
                            request,
                            site_id,
                            authorization=None):
        """Perform a POST request to /public/v{version}/site/updateclientindex.

        Updates an exisitng client index record at the specified business.
        This endpoint requires staff user credentials.

        Args:
            version (str): version of the api.
            request (UpdateSiteClientIndexRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            UpdateSiteClientIndexResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/site/updateclientindex")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateSiteClientIndexResponse.from_dictionary),
        ).execute()




"""
mindbodypublicapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import os

from apimatic_core.authentication.header_auth import HeaderAuth


class CustomHeaderAuthentication(HeaderAuth):
    """
    An authentication handler that applies `CustomHeaderAuthentication` to
    outgoing requests. It constructs the required credential values and integrates
    with the core authentication framework.
    """

    @property
    def error_message(self):
        """Return reason about the authentication failure."""
        return "CustomHeaderAuthentication: api_key is undefined."

    def __init__(self, auth_model):
        """
        Initialize the authentication handler with credential data.

        Args:
            auth_model: The credentials object used to generate the authorization
             header.

        """
        auth_params = {}
        if auth_model is not None \
                and auth_model.api_key is not None:
            auth_params["API-Key"] = auth_model.api_key
        super().__init__(auth_params=auth_params)


class CustomHeaderAuthenticationCredentials:
    """
    A model for authentication credentials. Provides simple validation,
    cloning support, and optional construction from environment variables.
    Suitable as a pattern for other auth models.
    """

    @property
    def api_key(self):
        """
        API Key Authentication.
        """
        return self._api_key

    def __init__(self, api_key):
        """
        Initialize the credentials.

        Args:
            api_key: The api_key property value to set.

        Raises:
            ValueError: If any required value is missing.

        """
        if api_key is None:
            raise ValueError("api_key cannot be None")
        self._api_key = api_key

    def clone_with(self, api_key=None):
        """
        Return a new instance with optional value overrides.

        Args:
            api_key: The api_key property value to set.

        """
        return CustomHeaderAuthenticationCredentials(api_key or self.api_key)

    @classmethod
    def from_environment(cls):
        """
        Create credentials from environment variables, if available.

        Returns:
            A credentials instance or ``None`` if values are missing.

        """
        api_key = os.getenv(
            "API_KEY",
            None,
        )

        if (api_key is None):
            return None

        return cls(
            api_key=api_key,
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetCategoriesRequest(object):
    """Implementation of the 'GetCategoriesRequest' model.

    Get Categories Request Model

    Attributes:
        category_ids (List[int]): When included, the response only contains details
            about the specified category Ids.
        sub_category_ids (List[int]): When included, the response only contains
            details about the specified subcategory Ids.
        service (bool): When `true`, the response only contains details about Revenue
            Categories.  When `false`, only Product Revenue Categories are returned.
            Default: **All Categories**
        active (bool): When `true`, the response only contains categories which are
            activated.   When `false`, only deactivated categories are returned.
            Default: **All Categories**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "category_ids": "CategoryIds",
        "sub_category_ids": "SubCategoryIds",
        "service": "Service",
        "active": "Active",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "category_ids",
        "sub_category_ids",
        "service",
        "active",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        category_ids=APIHelper.SKIP,
        sub_category_ids=APIHelper.SKIP,
        service=APIHelper.SKIP,
        active=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetCategoriesRequest instance."""
        # Initialize members of the class
        if category_ids is not APIHelper.SKIP:
            self.category_ids = category_ids
        if sub_category_ids is not APIHelper.SKIP:
            self.sub_category_ids = sub_category_ids
        if service is not APIHelper.SKIP:
            self.service = service
        if active is not APIHelper.SKIP:
            self.active = active
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        category_ids =\
            dictionary.get("CategoryIds")\
            if dictionary.get("CategoryIds")\
                else APIHelper.SKIP
        sub_category_ids =\
            dictionary.get("SubCategoryIds")\
            if dictionary.get("SubCategoryIds")\
                else APIHelper.SKIP
        service =\
            dictionary.get("Service")\
            if "Service" in dictionary.keys()\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(category_ids,
                   sub_category_ids,
                   service,
                   active,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _category_ids=(
            self.category_ids
            if hasattr(self, "category_ids")
            else None
        )
        _sub_category_ids=(
            self.sub_category_ids
            if hasattr(self, "sub_category_ids")
            else None
        )
        _service=(
            self.service
            if hasattr(self, "service")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"category_ids={_category_ids!r}, "
            f"sub_category_ids={_sub_category_ids!r}, "
            f"service={_service!r}, "
            f"active={_active!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _category_ids=(
            self.category_ids
            if hasattr(self, "category_ids")
            else None
        )
        _sub_category_ids=(
            self.sub_category_ids
            if hasattr(self, "sub_category_ids")
            else None
        )
        _service=(
            self.service
            if hasattr(self, "service")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"category_ids={_category_ids!s}, "
            f"sub_category_ids={_sub_category_ids!s}, "
            f"service={_service!s}, "
            f"active={_active!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateClientRewardsRequest(object):
    """Implementation of the 'UpdateClientRewardsRequest' model.

    Request object for using the API to Earn or Redeem reward points

    Attributes:
        client_id (str): The ID of the client that is getting rewards earned or
            redeemed.
        points (int): The amount of points the client is getting earned or redeemed,
            must be a positive number.
        source (str): If Action passed as **Earned**,    possible values are:  *
            Appointment Booking  * Class Booking  * Referral  * Sale    <br />Omit if
            Action passed as **Redeemed**.
        source_id (int): The unique identifier in the MINDBODY system for the
            **Source**. If Action is **Earned**, and an optional SourceID is
            provided, it is validated as follows:     * If Source is Appointment
            Booking, then a provided SourceID must be a valid Visit.AppointmentId for
            the indicated Client.  * If Source is **Class Booking**, then a provided
            SourceID must be a valid Visit.Id for the indicated client.  * If Source
            is **Sale**, then a provided SourceID must be a valid Sale.Id for the
            indicated client.   * If Source is **Referral**, then a provided SourceID
            must be a valid Client.Id (RelatedClientId) and have been referred by the
            indicated client (ClientRelationship.Id = -1).  If Action is
            **Redeemed**, and an optional SourceID is provided, then SourceID must be
            a valid Sale.Id for the indicated client, and refers to the sale where
            the indicated points were redeemed.
        action (str): Indicates if rewards are getting earned or redeemed.
            Possible values are:  *Earned  *Redeemed
        action_date_time (datetime): The date and time when the points were earned or
            redeemed in UTC format. This date may be in the past, however it may not
            be in the future.  Default: **current date/time**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "points": "Points",
        "action": "Action",
        "source": "Source",
        "source_id": "SourceId",
        "action_date_time": "ActionDateTime",
    }

    _optionals = [
        "source",
        "source_id",
        "action_date_time",
    ]

    def __init__(
        self,
        client_id=None,
        points=None,
        action=None,
        source=APIHelper.SKIP,
        source_id=APIHelper.SKIP,
        action_date_time=APIHelper.SKIP):
        """Initialize a UpdateClientRewardsRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.points = points
        if source is not APIHelper.SKIP:
            self.source = source
        if source_id is not APIHelper.SKIP:
            self.source_id = source_id
        self.action = action
        if action_date_time is not APIHelper.SKIP:
            self.action_date_time =\
                 APIHelper.apply_datetime_converter(
                action_date_time, APIHelper.RFC3339DateTime)\
                 if action_date_time else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        points =\
            dictionary.get("Points")\
            if dictionary.get("Points")\
                else None
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else None
        source =\
            dictionary.get("Source")\
            if dictionary.get("Source")\
                else APIHelper.SKIP
        source_id =\
            dictionary.get("SourceId")\
            if dictionary.get("SourceId")\
                else APIHelper.SKIP
        action_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ActionDateTime")).datetime\
            if dictionary.get("ActionDateTime") else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   points,
                   action,
                   source,
                   source_id,
                   action_date_time)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _points=self.points
        _source=(
            self.source
            if hasattr(self, "source")
            else None
        )
        _source_id=(
            self.source_id
            if hasattr(self, "source_id")
            else None
        )
        _action=self.action
        _action_date_time=(
            self.action_date_time
            if hasattr(self, "action_date_time")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"points={_points!r}, "
            f"source={_source!r}, "
            f"source_id={_source_id!r}, "
            f"action={_action!r}, "
            f"action_date_time={_action_date_time!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _points=self.points
        _source=(
            self.source
            if hasattr(self, "source")
            else None
        )
        _source_id=(
            self.source_id
            if hasattr(self, "source_id")
            else None
        )
        _action=self.action
        _action_date_time=(
            self.action_date_time
            if hasattr(self, "action_date_time")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"points={_points!s}, "
            f"source={_source!s}, "
            f"source_id={_source_id!s}, "
            f"action={_action!s}, "
            f"action_date_time={_action_date_time!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.client_with_suspension_info import (
    ClientWithSuspensionInfo,
)


class UpdateClientRequest(object):
    """Implementation of the 'UpdateClientRequest' model.

    Attributes:
        client (ClientWithSuspensionInfo): A Client DTO with Suspension Informatoin
        test (bool): When `true`, indicates that test mode is enabled. The method is
            validated, but no client data is added or updated.<br />  Default:
            **false**
        cross_regional_update (bool): When `true`, the updated information is
            propagated to all of the region’s sites where the client has a
            profile.<br />  When `false`, only the local client is updated.<br />
            Default: **true**<br />  Important: The fields below will automatically
            propagate cross-regionally when updated through the UpdateClient
            endpoint, regardless the CrossRegionalUpdate parameter is set to `true`
            or `false`.      * `RSSID`   * `Prefix`   * `Name (First, Middle, Last,
            Nickname)`   * `Email`   * `Birthday`   * `Phone (Home, Mobile, Work,
            Extension)`   * `Address`
        new_id (str): The new RSSID to be used for the client. Use `NewId` to assign
            a specific number to be a client’s ID. If that number is not available,
            the call returns an error. This RSSID must be unique within the
            subscriber’s site. If this is a cross-regional update, the RSSID must be
            unique across the region. If the requested number is already in use, an
            error is returned.  Note: NewId value cannot fall within the reserved
            default ID range (100000000 -&gt; 101000000)
        lead_channel_id (int): The ID of the Lead Channel ID from lead management. If
            this is supplied then it will map lead channel on the lead management.
            If this is not supplied then it will have Publicapi LeadChannelId.  This
            parameters required to track the lead channel if new client added to the
            location.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client": "Client",
        "test": "Test",
        "cross_regional_update": "CrossRegionalUpdate",
        "new_id": "NewId",
        "lead_channel_id": "LeadChannelId",
    }

    _optionals = [
        "test",
        "cross_regional_update",
        "new_id",
        "lead_channel_id",
    ]

    def __init__(
        self,
        client=None,
        test=APIHelper.SKIP,
        cross_regional_update=APIHelper.SKIP,
        new_id=APIHelper.SKIP,
        lead_channel_id=APIHelper.SKIP):
        """Initialize a UpdateClientRequest instance."""
        # Initialize members of the class
        self.client = client
        if test is not APIHelper.SKIP:
            self.test = test
        if cross_regional_update is not APIHelper.SKIP:
            self.cross_regional_update = cross_regional_update
        if new_id is not APIHelper.SKIP:
            self.new_id = new_id
        if lead_channel_id is not APIHelper.SKIP:
            self.lead_channel_id = lead_channel_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client =\
            ClientWithSuspensionInfo.from_dictionary(
                dictionary.get("Client"))\
                if dictionary.get("Client") else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        cross_regional_update =\
            dictionary.get("CrossRegionalUpdate")\
            if "CrossRegionalUpdate" in dictionary.keys()\
                else APIHelper.SKIP
        new_id =\
            dictionary.get("NewId")\
            if dictionary.get("NewId")\
                else APIHelper.SKIP
        lead_channel_id =\
            dictionary.get("LeadChannelId")\
            if dictionary.get("LeadChannelId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client,
                   test,
                   cross_regional_update,
                   new_id,
                   lead_channel_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client=self.client
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _cross_regional_update=(
            self.cross_regional_update
            if hasattr(self, "cross_regional_update")
            else None
        )
        _new_id=(
            self.new_id
            if hasattr(self, "new_id")
            else None
        )
        _lead_channel_id=(
            self.lead_channel_id
            if hasattr(self, "lead_channel_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client={_client!r}, "
            f"test={_test!r}, "
            f"cross_regional_update={_cross_regional_update!r}, "
            f"new_id={_new_id!r}, "
            f"lead_channel_id={_lead_channel_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client=self.client
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _cross_regional_update=(
            self.cross_regional_update
            if hasattr(self, "cross_regional_update")
            else None
        )
        _new_id=(
            self.new_id
            if hasattr(self, "new_id")
            else None
        )
        _lead_channel_id=(
            self.lead_channel_id
            if hasattr(self, "lead_channel_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client={_client!s}, "
            f"test={_test!s}, "
            f"cross_regional_update={_cross_regional_update!s}, "
            f"new_id={_new_id!s}, "
            f"lead_channel_id={_lead_channel_id!s}, "
            f")"
        )
